/*
==========================================================================================

	File:		configs.cp

	Contains:	Routines for dealing with command-line-based config files.

	Copyright:	 1998 by Christopher Nebel, all rights reserved.

	Change History (most recent first):
	
		<3>		 8/29/98	Neb		Go back to unmapped \n and \r.
		<2>		 8/26/98	Neb		Change ID of preferences file string.
		<1>		 8/23/98	Neb		Initial version.  readconfig and writeconfig created
									based on code from os0tc_ma.c; writeoptions classes
									created based on older writeoption_as functions.

==========================================================================================
*/

#include "configs.h"

#include <stdio.h>
#include <ctype.h>
#include <stdarg.h>
#include <Types.h>
#include <Resources.h>
#include <Folders.h>
#include <TextUtils.h>

#include "os.h"
#include "mstring.h"
#include "ossmac.h"
#include "common.r.h"

// =======================================================================================

static OSErr prefsfilepath(char *fnp, size_t fnl)
{
	#pragma unused(fnl)
	
	StringHandle	hPrefsName;
	FSSpec			prefs;
	OSErr			err = noErr;
	
	hPrefsName = GetString(kPreferencesFileNameID);
	if (!hPrefsName) {
		err = ResError();
	}
	else {
		HLock((Handle) hPrefsName);
		StringCopy_pp(prefs.name, *hPrefsName, sizeof(prefs.name));
		ReleaseResource((Handle) hPrefsName);
		
		err = FindFolder(kOnSystemDisk, kPreferencesFolderType, false, &prefs.vRefNum, &prefs.parID);
		if (err == noErr) {
			fsspectopath(&prefs, fnp);
		}
	}
	
	return noErr;
}

// ---------------------------------------------------------------------------------------

class FILE_t {
	private:
		FILE	*fp;
	public:
		FILE_t(const char *name, const char *mode)	{ this->fp = fopen(name, mode); }
		~FILE_t()			{ if (this->fp) fclose(this->fp); }
		operator FILE *()	{ return this->fp; }
};
		
// ---------------------------------------------------------------------------------------

int readconfig(const char *fname, const char *tname, const char *tname2, char *buf, int siz)
{
	const char *fn;
	char		prefs[256];
	
	if (fname == NULL) {
		if (prefsfilepath(prefs, 256) == noErr)
			fn = prefs;
	}
	else {
		fn = fname;
	}
	
	FILE_t		fp(fn, "r");
	
	if (fp) {
		char   *p;
		
		while (fgets(buf, siz, fp)) {
			/* First find a line that begins with the tool name.
			*/
			for (p = buf; isspace(*p); p++) ;
			if (strncmp(p, tname, strlen(tname)) == 0 ||
				(tname2 && strncmp(p, tname2, strlen(tname2)) == 0))
			{
				/* Got one!  Now get any continuation lines. */
				size_t	linelen;
				int		bufsiz = siz;
				
				goto L_init;
				while (*p == '\\') {
					if (bufsiz <= 0) break;
					fgets(p, bufsiz, fp);
				L_init:
					linelen = strlen(p);
					if (p[linelen-1] == '\n') p[--linelen] = '\0';
					linelen -= 1;
					bufsiz -= linelen;
					p += linelen;
				}
				
				return 0;
			}
		}
		return 2;
	}
	else
		return 1;
}

// ---------------------------------------------------------------------------------------

int writeconfig(const char *fname, const char *buf)
{
	const char *fn;
	char		prefs[256];
	
	if (fname == NULL) {
		if (prefsfilepath(prefs, 256) == noErr)
			fn = prefs;
	}
	else {
		fn = fname;
	}
	
	FILE   *fp;
	
	if ((fp = fopen(fn, "w")) != NULL) {
		fputs(buf, fp);
		putc('\n', fp);
		fclose(fp);
		os_settype(fn, OSFTPREF);
		return 0;
	}
	else
		return 1;
}

// =======================================================================================

void wrtoptargv_t::write(const char *format, ...)
{
	/* Write the option as its own string with terminating null. */
	
	va_list	ap;
	int		len;
	
	this->argv[this->argc++] = fbuf;
	va_start(ap, format);
	len = vsprintf(fbuf, format, ap);
	va_end(ap);
	
	fbuf += len + 1;
}

// ---------------------------------------------------------------------------------------

void wrtoptstring_t::write(const char *format, ...)
{
	/* Catenate the option to an already existing string. */
	
	va_list	ap;
	int		len;
	
	va_start(ap, format);
	len = vsprintf(fbuf, format, ap);
	va_end(ap);
	
	fbuf += len;
	*fbuf++ = ' ';
	*fbuf = '\0';
}

