/*
==========================================================================================

	File:		mac_tr.r

	Contains:	Resources for TADS Run-time.

	Copyright:	 1998 by Christopher Nebel, all rights reserved.

	Change History (most recent first):
	
		<3>		 9/22/98	Neb		Add resources from binary file.
		<2>		 8/26/98	Neb		Use new common.r.
		<1>		 7/21/98	Neb		Initial checkin.

==========================================================================================
*/

#define SystemSevenOrLater 1

#include <Types.r>
#include <Processes.r>
#include <Dialogs.r>
#include <Menus.r>
#include <Icons.r>


#define TADS_COMPONENT  "Run-time"

#include "common.r"

// =======================================================================================
// == Signature and size.
// ==

type 'TADR' as 'STR ';

resource 'TADR' (0) {
	"TADS: The Text Adventure Development System " TADSLEVEL
};

#if 0
/* CodeWarrior builds a SIZE(-1) resource for us. */
resource 'SIZE' (-1) {
	reserved,
	ignoreSuspendResumeEvents,
	reserved,
	canBackground,
	needsActivateOnFGSwitch,
	backgroundAndForeground,
	dontGetFrontClicks,
	ignoreChildDiedEvents,
	is32BitCompatible,
	isHighLevelEventAware,
	localAndRemoteHLEvents,
	notStationeryAware,
	dontUseTextEditServices,
	reserved,
	reserved,
	reserved,
	1024 * 1024,
	1024 * 1024
};
#endif


// =======================================================================================
// == Preferences resource and matching TMPL.
// ==

type 'TMPL' {
	array ItemArray {
		pstring;			/* Name of field */
		literal longint;	/* Field type    */
	};
};

resource 'TMPL' (128, "Pref") {
	{
		"Font size",			'DWRD',
		"Font name",			'P03F',
		"Window user size",		'RECT',
		"Window standard size",	'RECT'
	}
};

type 'Pref' {
	integer;		/* Font size */
	pstring[63];	/* Font name */
	rect;			/* Window user size */
	rect;			/* Window standard size */
};

resource 'Pref' (128) {
	9,
	"Monaco",
	{0, 0, 0, 0},
	{0, 0, 0, 0}
};

// =======================================================================================
// == Dialog, alert, and window resources.
// ==

// ...............................................
// .. About

resource 'DLOG' (130, "About") {
	{100, 142, 316, 512},
	dBoxProc,
	visible,
	noGoAway,
	0x0,
	130,
	"About TADS",
	alertPositionMainScreen
};

resource 'DITL' (130, "About") {
	{	/* array DITLarray: 4 elements */
		/* [1] */
		{172, 158, 192, 218},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{59, 57, 82, 329},
		StaticText {
			disabled,
			"The Text Adventure Development System\n"
		},
		/* [3] */
		{26, 167, 48, 202},
		StaticText {
			disabled,
			"TADS"
		},
		/* [4] */
		{96, 32, 153, 349},
		StaticText {
			disabled,
			"This game was developed with TADS, the Text "
			"Adventure Development System, version " TADSLEVEL
			", Copyright  1990-98 by Michael J. Roberts."
		}
	}
};

// ...............................................
// .. Startup options

resource 'DLOG' (128, "Startup options") {
	{42, 5, 334, 500},
	documentProc,
	visible,
	noGoAway,
	0x0,
	128,
	"TADS Run-Time v" TADSLEVEL,
	staggerMainScreen
};

resource 'DITL' (128, "Startup options") {
	{	/* array DITLarray: 26 elements */
		/* [1] */
		{7, 133, 28, 407},
		StaticText {
			disabled,
			""
		},
		/* [2] */
		{7, 13, 26, 120},
		StaticText {
			disabled,
			"Game to run:"
		},
		/* [3] */
		{7, 412, 27, 478},
		Button {
			enabled,
			"Select"
		},
		/* [4] */
		{263, 319, 283, 385},
		Button {
			enabled,
			"Run"
		},
		/* [5] */
		{263, 396, 283, 462},
		Button {
			enabled,
			"Quit"
		},
		/* [6] */
		{211, 16, 227, 149},
		CheckBox {
			enabled,
			"Allow Swapping"
		},
		/* [7] */
		{231, 90, 252, 339},
		StaticText {
			disabled,
			"<Default>"
		},
		/* [8] */
		{231, 15, 253, 85},
		StaticText {
			disabled,
			"Swap File:"
		},
		/* [9] */
		{231, 412, 251, 478},
		Button {
			enabled,
			"Select"
		},
		/* [10] */
		{262, 15, 278, 160},
		StaticText {
			disabled,
			"Maximum Cache Size:"
		},
		/* [11] */
		{262, 166, 278, 246},
		EditText {
			disabled,
			""
		},
		/* [12] */
		{0, 655, 21, 928},
		CheckBox {
			enabled,
			"Version 1 Compatibility Mode"
		},
		/* [13] */
		{135, 90, 156, 400},
		StaticText {
			disabled,
			""
		},
		/* [14] */
		{165, 16, 181, 236},
		CheckBox {
			enabled,
			"Save output to file"
		},
		/* [15] */
		{184, 90, 205, 400},
		StaticText {
			disabled,
			""
		},
		/* [16] */
		{90, 412, 110, 478},
		Button {
			enabled,
			"Select"
		},
		/* [17] */
		{184, 412, 204, 478},
		Button {
			enabled,
			"Select"
		},
		/* [18] */
		{69, 16, 85, 236},
		CheckBox {
			enabled,
			"Generate Command Script"
		},
		/* [19] */
		{114, 16, 130, 236},
		CheckBox {
			enabled,
			"Read Command Script"
		},
		/* [20] */
		{90, 90, 111, 400},
		StaticText {
			disabled,
			""
		},
		/* [21] */
		{135, 412, 155, 478},
		Button {
			enabled,
			"Select"
		},
		/* [22] */
		{37, 13, 53, 91},
		StaticText {
			disabled,
			"Stack Size:"
		},
		/* [23] */
		{37, 97, 53, 157},
		EditText {
			disabled,
			"200"
		},
		/* [24] */
		{37, 209, 53, 286},
		StaticText {
			disabled,
			"Heap Size:"
		},
		/* [25] */
		{37, 292, 53, 352},
		EditText {
			disabled,
			"2048"
		},
		/* [26] */
		{231, 343, 251, 409},
		Button {
			enabled,
			"Default"
		}
	}
};

// ...............................................
// .. Open game file

resource 'DLOG' (129, "SFOpen", purgeable) {
	{0, 0, 238, 356},
	dBoxProc,
	invisible,
	noGoAway,
	0x0,
	129,
	"",
	alertPositionMainScreen
};

resource 'DITL' (129, "SFOpen", purgeable) {
	{	/* array DITLarray: 13 elements */
		/* [1] */
		{138, 256, 156, 336},
		Button {
			enabled,
			"Open"
		},
		/* [2] */
		{0, 699, 80, 717},
		Button {
			enabled,
			""
		},
		/* [3] */
		{163, 256, 181, 336},
		Button {
			enabled,
			"Cancel"
		},
		/* [4] */
		{39, 232, 59, 347},
		UserItem {
			disabled
		},
		/* [5] */
		{68, 256, 86, 336},
		Button {
			enabled,
			"Eject"
		},
		/* [6] */
		{93, 256, 111, 336},
		Button {
			enabled,
			"Drive"
		},
		/* [7] */
		{39, 12, 185, 229},
		UserItem {
			enabled
		},
		/* [8] */
		{39, 229, 185, 246},
		UserItem {
			enabled
		},
		/* [9] */
		{124, 252, 125, 340},
		UserItem {
			disabled
		},
		/* [10] */
		{0, 660, 101, 756},
		StaticText {
			disabled,
			""
		},
		/* [11] */
		{188, 256, 206, 337},
		Button {
			enabled,
			"Options"
		},
		/* [12] */
		{193, 48, 211, 216},
		RadioButton {
			enabled,
			"Show TADS Games Only"
		},
		/* [13] */
		{211, 48, 229, 160},
		RadioButton {
			enabled,
			"Show All Files"
		}
	}
};

// ...............................................
// .. Font size

resource 'DLOG' (131, "Font size") {
	{94, 62, 170, 254},
	movableDBoxProc,
	invisible,
	noGoAway,
	0x0,
	131,
	"",
	alertPositionMainScreen
};

resource 'DITL' (131) {
	{	/* array DITLarray: 5 elements */
		/* [1] */
		{44, 120, 64, 180},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{44, 48, 64, 108},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{8, 88, 24, 128},
		EditText {
			enabled,
			""
		},
		/* [4] */
		{8, 8, 24, 75},
		StaticText {
			disabled,
			"Font size:"
		},
		/* [5] */
		{8, 136, 24, 183},
		StaticText {
			disabled,
			"points"
		}
	}
};

// ...............................................
// .. Game window (obsolete, now calculated)

#if 0
resource 'WIND' (128) {
	{40, 2, 348, 512},
	documentProc,
	visible,
	noGoAway,
	0x0,
	"TADS"
};
#endif


// =======================================================================================
// == Menus.
// ==

resource 'MENU' (128) {
	128,
	textMenuProc,
	0x7FFFFFFD,
	enabled,
	apple,
	{
		"About TADS", noIcon, noKey, noMark, plain,
		"-", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (129) {
	129,
	textMenuProc,
	0x7FFFFFF7,
	enabled,
	"File",
	{
		"Save", noIcon, "S", noMark, plain,
		"Restore", noIcon, noKey, noMark, plain,
		"Restart", noIcon, noKey, noMark, plain,
		"-", noIcon, noKey, noMark, plain,
		"Quit", noIcon, "Q", noMark, plain
	}
};

resource 'MENU' (130) {
	130,
	textMenuProc,
	0x7FFFFFFD,
	enabled,
	"Edit",
	{
		"Undo", noIcon, "Z", noMark, plain,
		"-", noIcon, noKey, noMark, plain,
		"Cut", noIcon, "X", noMark, plain,
		"Copy", noIcon, "C", noMark, plain,
		"Paste", noIcon, "V", noMark, plain,
		"Clear", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (132) {
	132,
	textMenuProc,
	allEnabled,
	enabled,
	"Travel",
	{
		"North", noIcon, noKey, noMark, plain,
		"South", noIcon, noKey, noMark, plain,
		"East", noIcon, noKey, noMark, plain,
		"West", noIcon, noKey, noMark, plain,
		"Northeast", noIcon, noKey, noMark, plain,
		"Northwest", noIcon, noKey, noMark, plain,
		"Southeast", noIcon, noKey, noMark, plain,
		"Southwest", noIcon, noKey, noMark, plain,
		"Up", noIcon, noKey, noMark, plain,
		"Down", noIcon, noKey, noMark, plain,
		"In", noIcon, noKey, noMark, plain,
		"Out", noIcon, noKey, noMark, plain
	}
};

resource 'MENU' (131) {
	131,
	textMenuProc,
	0x7FFFFFEF,
	enabled,
	"Commands",
	{
		"Inventory", noIcon, "I", noMark, plain,
		"Look", noIcon, noKey, noMark, plain,
		"Score", noIcon, noKey, noMark, plain,
		"Wait", noIcon, noKey, noMark, plain,
		"-", noIcon, noKey, noMark, plain,
		"Take", noIcon, "T", noMark, plain,
		"Drop", noIcon, "D", noMark, plain
	}
};

resource 'MENU' (133) {
	133,
	textMenuProc,
	allEnabled,
	enabled,
	"Font",
	{
	}
};

resource 'MENU' (134) {
	134,
	textMenuProc,
	0x7FFFFFBF,
	enabled,
	"Size",
	{
		"9", noIcon, noKey, noMark, plain,
		"10", noIcon, noKey, noMark, plain,
		"12", noIcon, noKey, noMark, plain,
		"14", noIcon, noKey, noMark, plain,
		"18", noIcon, noKey, noMark, plain,
		"24", noIcon, noKey, noMark, plain,
		"-", noIcon, noKey, noMark, plain,
		"Other", noIcon, noKey, noMark, plain,
		"Smaller", noIcon, "[", noMark, plain,
		"Larger", noIcon, "]", noMark, plain
	}
};


// =======================================================================================
// == BNDL and FREF resources.
// ==

resource 'BNDL' (128) {
	'TADR',
	0,
	{
		'FREF',
		{
			0, 128,
			1, 129,
			2, 130,
			3, 131,
			4, 132
		},
		
		'ICN#',
		{
			0, 128,
			1, 129,
			2, 130,
			3, 131,
			4, 132
		}
	}
};

resource 'FREF' (128) {
	'APPL',
	0,
	""
};

resource 'FREF' (129) {
	'TADG',
	1,
	""
};

resource 'FREF' (130) {
	'TEXT',
	2,
	""
};

resource 'FREF' (131) {
	'SWAP',
	3,
	""
};

resource 'FREF' (132) {
	'TADV',
	4,
	""
};

// =======================================================================================
// == Icons.
// ==

// ---------------------------------------------------------------------------------------
// -- Large icons.

// ...............................................
// .. ICN#

resource 'ICN#' (128) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 0000 0000 0000 FFFF FFF8 8000 0008"
		$"8F91 C708 8229 281C 8229 2624 827D 2154"
		$"8245 CE98 8000 0138 FFFF DE68 8000 24C8"
		$"8000 49C8 8000 9328 8001 2618 8002 4E08"
		$"8002 9A07 8071 7C07 806E 8007 8052 E007"
		$"8027 1C07 8025 13C7 8011 10BF 8017 110F"
		$"8038 9208 81C0 5408 8E00 3808 B1FF FFF8"
		$"8E00 3808 81C0 5408 8038 9208 FFFF FFF8",
		/* [2] */
		$"0000 0000 0000 0000 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFFC FFFF FFFC FFFF FFFC"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
	}
};

resource 'ICN#' (129) {
	{	/* array: 2 elements */
		/* [1] */
		$"FFFF F800 8000 0C00 BE47 1A00 88A4 A900"
		$"88A4 9880 89F4 8840 8917 3FE0 8000 0020"
		$"FFFF FFE0 8000 0020 8000 1020 8000 1020"
		$"8000 2820 8000 2820 8000 2820 8000 5420"
		$"8000 5420 8070 5420 806C 9260 8053 93A0"
		$"8028 9220 8025 1160 8013 11A0 8017 11E0"
		$"8038 9220 81C0 5420 8E00 3830 B1FF FFFC"
		$"8E00 383F 81C0 543F 8038 923C FFFF FFF0",
		/* [2] */
		$"FFFF F800 FFFF FC00 FFFF FE00 FFFF FF00"
		$"FFFF FF80 FFFF FFC0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFF0 FFFF FFFC"
		$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFF0"
	}
};

resource 'ICN#' (130) {
	{	/* array: 2 elements */
		/* [1] */
		$"FFFF F800 8000 0C00 BE47 1A00 88A4 A900"
		$"88A4 9880 89F4 8840 8917 3FE0 8000 0020"
		$"FFFF FFE0 8000 0020 8000 1020 8780 1020"
		$"8840 2820 9320 2820 97A0 2820 97A0 0020"
		$"9327 6F20 8840 0020 8788 9220 8002 8220"
		$"8020 9220 8785 0120 8841 1120 9026 01A0"
		$"9028 9020 9020 0020 9027 6F30 A840 003C"
		$"8780 103F 8000 543F 8000 003C FFFF FFF0",
		/* [2] */
		$"FFFF F800 FFFF FC00 FFFF FE00 FFFF FF00"
		$"FFFF FF80 FFFF FFC0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFF0 FFFF FFFC"
		$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFF0"
	}
};

resource 'ICN#' (131) {
	{	/* array: 2 elements */
		/* [1] */
		$"FFFF F800 8000 0C00 BE47 1A00 88A4 A900"
		$"88A4 9880 89F4 8840 8917 3FE0 8000 0020"
		$"FFFF FFE0 8000 0020 8000 0020 8001 0020"
		$"8006 8020 8005 C020 801B E020 8017 F020"
		$"806F D820 805F B020 81BF 7820 817E D820"
		$"86FD F820 86FB 6820 8777 E020 87AD A020"
		$"85DF 8020 84F6 8020 807E 0030 802A 003C"
		$"8008 003F 8008 003F 8000 003C FFFF FFF0",
		/* [2] */
		$"FFFF F800 FFFF FC00 FFFF FE00 FFFF FF00"
		$"FFFF FF80 FFFF FFC0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFF0 FFFF FFFC"
		$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFF0"
	}
};

resource 'ICN#' (132) {
	{	/* array: 2 elements */
		/* [1] */
		$"FFFF F800 8000 0C00 BE47 1A00 88A4 A900"
		$"88A4 9880 89F4 8840 8917 3FE0 8000 0020"
		$"FFFF FFE0 8000 0020 8000 1020 8000 1020"
		$"8000 2820 8000 2820 8000 2820 8000 5430"
		$"81FF FFE8 8080 0008 8040 0008 8020 0008"
		$"8040 0008 8080 0008 81FF FFF0 8007 1160"
		$"8038 9220 81C0 5420 8E00 1030 B1FF FFFC"
		$"8E00 103F 81C0 543F 8038 923C FFFF FFF0",
		/* [2] */
		$"FFFF F800 FFFF FC00 FFFF FE00 FFFF FF00"
		$"FFFF FF80 FFFF FFC0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFE0 FFFF FFF0"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF8 FFFF FFF8"
		$"FFFF FFF8 FFFF FFF8 FFFF FFF0 FFFF FFE0"
		$"FFFF FFE0 FFFF FFE0 FFFF FFF0 FFFF FFFC"
		$"FFFF FFFF FFFF FFFF FFFF FFFC FFFF FFF0"
	}
};

// ...............................................
// .. icl4

resource 'icl4' (128) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF F000"
	$"F000 0000 0000 0000 0000 0000 0000 F000"
	$"F000 FFFF F00F 000F FF00 CFFF 0000 F000"
	$"F000 00F0 00E0 E00F 0CF0 F000 000F FF00"
	$"F000 00F0 0CF0 FC0F 00F0 CFFC 00F4 4F00"
	$"F000 00F0 0EFF FE0F 0CF0 000F 0F1F 3F00"
	$"F000 00F0 CF00 0FCF FF00 FFFC F12F F000"
	$"F000 0000 0000 0000 0000 000F 12FF F000"
	$"FFFF FFFF FFFF FFFF FFCF FFF1 2FFC F000"
	$"F000 0000 0000 0000 00F0 DF12 FF0C F000"
	$"F000 0000 0000 0000 0FCD F12F FF0C F000"
	$"F000 0000 0000 0000 F0DF 12FF DDFC F000"
	$"F000 0000 0000 000F CDF1 2FFD DC0F F000"
	$"F000 0000 0000 00F0 DF12 FFFD C0C0 F000"
	$"F000 0000 0000 00FD F12F FCFC 0C0C 0FFF"
	$"F000 0000 0FFF 000F 1FFF FFC0 C0C0 DFFF"
	$"F000 0000 0FDC FFF1 FC0C 0C0C 0C0C DFFF"
	$"F000 0000 0F7D CCF2 FFFD DDD0 C0C0 DFFF"
	$"F000 0000 00F7 DFFF F66F FFDD DD0C DFFF"
	$"F000 0000 00F7 7FDF 666E DDFF FFDD DFFF"
	$"F000 0000 000F 77DF 777E CCCD E6FF FFFF"
	$"F000 0000 000F 7FFD 777D CCCE 7766 FFFF"
	$"F000 0000 00FF FCCC D77D 00D7 7776 F000"
	$"F000 000F FFCC CCCC CD7D 0D77 7776 F000"
	$"F000 FFFC CCCC CCCC CCDD D777 7776 F000"
	$"F0FF CCCD DDDD DDDD DDDD DDDD DDDE F000"
	$"F000 FFF7 7777 7777 77DD DCCC CCCD F000"
	$"F000 000F FF77 7777 7DCD 7DCC CCCD F000"
	$"F000 0000 00FF F777 DCCD 77DC CCCD F000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF F0"
};

resource 'icl4' (129) {
	$"FFFF FFFF FFFF FFFF FFFF F000 0000 0000"
	$"F000 0000 0000 0000 0000 FF00 0000 0000"
	$"F0FF FFF0 0F00 0FFF 00CF FCF0 0000 0000"
	$"F000 F000 E0E0 0F0C F0F0 F0CF 0000 0000"
	$"F000 F00C F0FC 0F00 F0CF F00C F000 0000"
	$"F000 F00E FFFE 0F0C F000 F0CC CF00 0000"
	$"F000 F0CF 000F CFFF 00FF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0DDD DDF0 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 0000 000F 0000 0CF0 0000"
	$"F000 0000 0000 0000 000F 0000 0CF0 0000"
	$"F000 0000 0000 0000 00FC F000 0CF0 0000"
	$"F000 0000 0000 0000 00FC F000 0CF0 0000"
	$"F000 0000 0000 0000 00FC F000 0CF0 0000"
	$"F000 0000 0000 0000 0F7D CF00 0CF0 0000"
	$"F000 0000 0000 0000 0F7D CF00 0CF0 0000"
	$"F000 0000 0FFF 0000 0F7D CF00 0CF0 0000"
	$"F000 0000 0FDC FF00 F77D CCF0 0FF0 0000"
	$"F000 0000 0F7D CCFF F77D CCFF F7F0 0000"
	$"F000 0000 00F7 DCCC F77D CCF7 77F0 0000"
	$"F000 0000 00F7 7DCF 777D CCCF 7DF0 0000"
	$"F000 0000 000F 77DF 777D CCCF DCF0 0000"
	$"F000 0000 000F 7FFD 777D CCCD FFF0 0000"
	$"F000 0000 00FF FCCC D77D CCD7 77F0 0000"
	$"F000 000F FFCC CCCC CD7D CD77 77F0 0000"
	$"F000 FFFC CCCC CCCC CCDD D777 77FE 0000"
	$"F0FF CCCD DDDD DDDD DDDD DDDD DDFE EE00"
	$"F000 FFF7 7777 7777 77DD DCCC CCFE EEEE"
	$"F000 000F FF77 7777 7DCD 7DCC CCFE EEEE"
	$"F000 0000 00FF F777 DCCD 77DC CCFE EE00"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFE"
};

resource 'icl4' (130) {
	$"FFFF FFFF FFFF FFFF FFFF F000 0000 0000"
	$"F000 0000 0000 0000 0000 FF00 0000 0000"
	$"F0FF FFF0 0F00 0FFF 00CF FCF0 0000 0000"
	$"F000 F000 E0E0 0F0C F0F0 F0CF 0000 0000"
	$"F000 F00C F0FC 0F00 F0CF F00C F000 0000"
	$"F000 F00E FFFE 0F0C F000 F0CC CF00 0000"
	$"F000 F0CF 000F CFFF 00FF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0DDD DDF0 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 0000 000C 0000 0CF0 0000"
	$"F000 0AFF A000 0000 000C 0000 0CF0 0000"
	$"F000 AEEE DA00 0000 00CC C000 0CF0 0000"
	$"F00A EEAA DCA0 0000 00CC C000 0CF0 0000"
	$"F00F EAFF ACF0 0000 00CC C000 0CF0 0000"
	$"F00F EAFF ACF0 0000 0CCC 0C00 0CF0 0000"
	$"F00A DDAA C0A0 0FFF 0FFC FFFF 0CF0 0000"
	$"F000 ACCC 0ACC 0000 0CCC 0C00 0CF0 0000"
	$"F000 0AFF ACC0 CC00 CCCC 00C0 0CF0 0000"
	$"F000 0000 0CCC 00CC CCCC 00CC CCF0 0000"
	$"F000 0000 00CC C000 CCCC 00CC CCF0 0000"
	$"F000 0AFF A0CC CC0C CCCC 000C CCF0 0000"
	$"F000 AC00 CA0C CCCC CCCC 000C CCF0 0000"
	$"F00A C00C CCAC CCCC CCCC 000C CCF0 0000"
	$"F00F 00CC CCFC C000 CCCC 00CC CCF0 0000"
	$"F00F 0CCC CDF0 0000 0CCC 0CCC CCF0 0000"
	$"F00A CCCC DDA0 0FFF 0FFC FFFF CCFE 0000"
	$"F0CC ACCD DACC CCCC CCCC CCCC CCFE EE00"
	$"F000 0AFF ACCC CCCC CCCC C000 0CFE EEEE"
	$"F000 000C CCCC CCCC CC0C CC00 0CFE EEEE"
	$"F000 0000 00CC CCCC C00C CCC0 0CFE EE00"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFE"
};

resource 'icl4' (131) {
	$"FFFF FFFF FFFF FFFF FFFF F000 0000 0000"
	$"F000 0000 0000 0000 0000 FF00 0000 0000"
	$"F0FF FFF0 0F00 0FFF 00CF FCF0 0000 0000"
	$"F000 F000 E0E0 0F0C F0F0 F0CF 0000 0000"
	$"F000 F00C F0FC 0F00 F0CF F00C F000 0000"
	$"F000 F00E FFFE 0F0C F000 F0CC CF00 0000"
	$"F000 F0CF 000F CFFF 00FF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0CCC CCF0 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 000D 0000 0000 0CF0 0000"
	$"F000 0000 0000 0DD0 D000 0000 0CF0 0000"
	$"F000 0000 0000 0F0D DD00 0000 0CF0 0000"
	$"F000 0000 000D D0DD DDD0 0000 0CF0 0000"
	$"F000 0000 000F 0DDD DDDD 0000 0CF0 0000"
	$"F000 0000 0DD0 DDDD DDCF F000 0CF0 0000"
	$"F000 0000 0F0D DDDD DCFF 0000 0CF0 0000"
	$"F000 000D D0DD DDDD CFFF D000 0CF0 0000"
	$"F000 000F 0DDD DDDC FF0E D000 0CF0 0000"
	$"F000 0DD0 DDDD DDCF FFDE D000 0CF0 0000"
	$"F000 0DFC DDDD DCFF 0ED0 D000 0CF0 0000"
	$"F000 0DFD CDDD CFFF DED0 0000 0CF0 0000"
	$"F000 0DFD DCDC FF0E D0D0 0000 0CF0 0000"
	$"F000 0D0F DDCF FFDE D000 0000 0CF0 0000"
	$"F000 0D00 FDDF 0ED0 D000 0000 0CF0 0000"
	$"F000 0000 0FDF DED0 0000 0000 0CFE 0000"
	$"F000 0000 00F0 D0D0 0000 0000 0CFE EE00"
	$"F000 0000 0000 D000 0000 0000 0CFE EEEE"
	$"F000 0000 0000 D000 0000 0000 0CFE EEEE"
	$"F000 0000 0000 0000 0000 0000 0CFE EE00"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFE"
};

resource 'icl4' (132) {
	$"FFFF FFFF FFFF FFFF FFFF F000 0000 0000"
	$"F000 0000 0000 0000 0000 FF00 0000 0000"
	$"F0FF FFF0 0F00 0FFF 00CF FCF0 0000 0000"
	$"F000 F000 E0E0 0F0C F0F0 F0CF 0000 0000"
	$"F000 F00C F0FC 0F00 F0CF F00C F000 0000"
	$"F000 F00E FFFE 0F0C F000 F0CC CF00 0000"
	$"F000 F0CF 000F CFFF 00FF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0DDD DDF0 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF0 0000"
	$"F000 0000 0000 0000 0000 0000 0CF0 0000"
	$"F000 0000 0000 0000 000C 0000 0CF0 0000"
	$"F000 0000 0000 0000 000C 0000 0CF0 0000"
	$"F000 0000 0000 0000 00CC C000 0CF0 0000"
	$"F000 0000 0000 0000 00CC C000 0CF0 0000"
	$"F000 0000 0000 0000 0CCC CC00 0CF0 0000"
	$"F000 0000 0000 0000 0CCC 0C00 0CFF 0000"
	$"F000 000F FFFF FFFF FFFF FFFF FFF2 F000"
	$"F000 0000 F222 2222 2222 2222 2223 F000"
	$"F000 0000 0F33 3333 3333 3333 3333 F000"
	$"F000 0000 0CF3 3333 3333 3333 3333 F000"
	$"F000 0000 0F33 3333 3333 3333 3333 F000"
	$"F000 0000 F333 3333 3333 3333 3333 F000"
	$"F000 000F FFFF FFFF FFFF FFFF FFFF 0000"
	$"F000 0000 CCCC CDDD CCCD CCCD DDF0 0000"
	$"F000 0000 00CC C000 CCCC 00CC CCF0 0000"
	$"F000 00CC CC00 0000 0CCC 0CCC CCF0 0000"
	$"F00C CCC0 0000 0000 00CC CCCC CCFE 0000"
	$"F0CC CCCC CCCC CCCC CCCC CCCC CCFE EE00"
	$"F00C CCCC CCCC CCCC CCCC C000 0CFE EEEE"
	$"F000 00CC CCCC CCCC CC0C CC00 0CFE EEEE"
	$"F000 0000 0CCC CCCC C00C CCC0 0CFE EE00"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFE"
};

// ...............................................
// .. icl8

resource 'icl8' (128) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FF00 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 FF00 0000"
	$"FF00 F5F5 FFFF FFFF FFF5 F5FF F5F5 F5FF"
	$"FFFF F5F5 2BFF FFFF F5F5 F5F5 FF00 0000"
	$"FF00 F5F5 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF"
	$"F52B FFF5 FFF5 F5F5 F5F5 F5FF FFFF 0000"
	$"FF00 F5F5 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF"
	$"F5F5 FFF5 2BFF FF2B F5F5 FF13 13FF 0000"
	$"FF00 F5F5 F5F5 FFF5 F5FB FFFF FFFB F5FF"
	$"F52B FFF5 F5F5 F5FF F5FF 05FF D8FF 0000"
	$"FF00 F5F5 F5F5 FFF5 F6FF F5F5 F5FF F6FF"
	$"FFFF F5F5 FFFF FF2B FF05 33FF FF00 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F5 F5FF 0533 FFFF FF00 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF 2BFF FFFF FF05 33FF FF2B FF00 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 FF08 33FF 0533 FFFF F5F6 FF00 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F5FF 0833 FF05 33FF FFFF F5F6 FF00 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"FF08 33FF 0533 FFFF 3333 FFF6 FF00 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F5FF"
	$"0833 FF05 33FF FF33 3333 08FF FF00 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 FF08"
	$"33FF 0533 FFFF FF33 3308 0808 FF00 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 FF33"
	$"FF05 33FF FFF8 FF33 0808 0808 08FF FFFF"
	$"FF00 00F5 00F5 00F5 00FD FDFC F7F5 F5FF"
	$"05FF FFFF FFFF 0808 0808 0808 33FF FFFF"
	$"FF00 F500 F500 F500 F5FD FA2A FDFD FF05"
	$"FF08 0808 0808 0808 0808 0808 33FF FFFF"
	$"FF00 00F5 00F5 00F5 00FC 54FA 2A2A FF33"
	$"FFFF FF33 3333 3308 0808 0808 33FF FFFF"
	$"FF00 F500 F500 F500 F5F7 FD54 FAFF FFFF"
	$"FDAB ABFF FFFF 3333 3333 0808 33FF FFFF"
	$"FF00 00F5 00F5 00F5 00F5 FD54 54FF FAFD"
	$"7F7F 7FFC F9F9 FFFF FFFF 3333 33FF FFFF"
	$"FF00 F500 F500 F500 F500 F8FD 5454 FAFD"
	$"5454 54FB F7F7 F7F9 FCAB FFFF FFFF FFFF"
	$"FF00 00F5 00F5 00F5 00F5 00FD 54FD FDFA"
	$"5454 54FA F7F7 F7FB 7F7F ABAB FFFF FFFF"
	$"FF00 F500 F500 F500 F5F8 FDFD FD2A 2A2A"
	$"FA54 54FA F5F5 FA54 5454 547F FF00 0000"
	$"FF00 00F5 00F5 F8FD FDFC 2A2A 2A2A 2A2A"
	$"2AFA 54FA F5FA 5454 5454 547F FF00 0000"
	$"FF00 F5F7 FDFD FC2A 2A2A 2A2A 2A2A 2A2A"
	$"2A2A FAFA FA54 5454 5454 547F FF00 0000"
	$"FF00 FDFD F7F7 F7FA FAFA FAFA FAFA FAFA"
	$"FAFA FAFA FAFA FAFA FAFA FAFA FF00 0000"
	$"FF00 F5F7 FDFD FC54 5454 5454 5454 5454"
	$"5454 FAFA FA2B 2B2B 2B2B 2B54 FFF5 00F5"
	$"FF00 00F5 00F5 F8FD FDFC 5454 5454 5454"
	$"54FA 2BFA 54FA 2B2B 2B2B 2B54 FFF5 F5F5"
	$"FF00 F500 F500 F500 F5F8 FDFD FC54 5454"
	$"FA2A 2AFA 5454 FA2A 2A2A 2A54 FFF5 F5F5"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFF5 F5"
};

resource 'icl8' (129) {
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF 0000 0000 0000 0000 0000"
	$"FF00 FFFF FFFF FFF5 F5FF F5F5 F5FF FFFF"
	$"F5F5 2BFF FFF8 FF00 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF F52B"
	$"FFF5 FFF5 FF00 F8FF 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF F5F5"
	$"FFF5 2BFF FF00 00F8 FF00 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5FB FFFF FFFB F5FF F52B"
	$"FFF5 F5F5 FFF5 F6F6 F8FF 0000 0000 0000"
	$"FF00 F5F5 FFF5 F6FF F5F5 F5FF F6FF FFFF"
	$"F5F5 FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F9 F9F9 F9F9 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F5FD F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 F7FD F7F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 FDF7 FD00 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 FDF7 FDF5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F5F8 FCF7 FCF8 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00FD 54FA 2AFD 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F5FD 54FA 2AFD F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00FD FDFC F7F5 00F5"
	$"F8FC 54FA 2AFC F8F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F5FD FA2A FDFD F800"
	$"FD54 54FA 2A2A FD00 F8FD FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00FC 54FA 2A2A FDFD"
	$"FD54 54FA 2A2A FDFD FD7F FF00 0000 0000"
	$"FF00 F500 F500 F500 F5F7 FD54 FA2A 2A2A"
	$"FD54 54FA 2A2A FD54 547F FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 FD54 54FA 2AFD"
	$"5454 54FA 2A2A 2AFD 54FA FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F8FD 5454 FAFD"
	$"5454 54FA 2A2A 2AFD FA54 FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00FD 54FD FDFA"
	$"5454 54FA 2A2A 2AFA FDFD FF00 0000 0000"
	$"FF00 F500 F500 F500 F5F8 FDFD FD2A 2A2A"
	$"FA54 54FA 2A2A FA54 547F FF00 0000 0000"
	$"FF00 00F5 00F5 F8FD FDFC 2A2A 2A2A 2A2A"
	$"2AFA 54FA 2AFA 5454 547F FF00 0000 0000"
	$"FF00 F5F7 FDFD FC2A 2A2A 2A2A 2A2A 2A2A"
	$"2A2A FAFA FA54 5454 547F FFFC 0000 0000"
	$"FF00 FDFD F7F7 F7FA FAFA FAFA FAFA FAFA"
	$"FAFA FAFA FAFA FAFA FAFA FFFC FCFC 0000"
	$"FF00 F5F7 FDFD FC54 5454 5454 5454 5454"
	$"5454 FAFA FA2A 2A2A 2A54 FFFC FCFC FCFC"
	$"FF00 00F5 00F5 F8FD FDFC 5454 5454 5454"
	$"54FA 2AFA 54FA 2A2A 2A54 FFFC FCFC FCFC"
	$"FF00 F500 F500 F500 F5F8 FDFD FD54 5454"
	$"FA2A 2AFA 5454 FA2A 2A54 FFFC FCFC 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFC"
};

resource 'icl8' (130) {
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF 0000 0000 0000 0000 0000"
	$"FF00 FFFF FFFF FFF5 F5FF F5F5 F5FF FFFF"
	$"F5F5 2BFF FFF8 FF00 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF F52B"
	$"FFF5 FFF5 FF00 F8FF 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF F5F5"
	$"FFF5 2BFF FF00 00F8 FF00 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5FB FFFF FFFB F5FF F52B"
	$"FFF5 F5F5 FFF5 F6F6 F8FF 0000 0000 0000"
	$"FF00 F5F5 FFF5 F6FF F5F5 F5FF F6FF FFFF"
	$"F5F5 FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F9 F9F9 F9F9 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F5F8 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FD FFFF FDF5 00F5 00F5 00F5"
	$"00F5 00F8 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 FDFC FBFB FAFD F500 F500 F500"
	$"F500 F8F6 F800 F500 F52B FF00 0000 0000"
	$"FF00 00FD FCFB FDFD F9F8 FDF5 00F5 00F5"
	$"00F5 F8F6 F8F5 00F5 002B FF00 0000 0000"
	$"FF00 F5FF FBFD FFFF FDF7 FF00 F500 F500"
	$"F5F6 F7F6 F8F6 F500 F52B FF00 0000 0000"
	$"FF00 00FF FBFD FFFF FDF6 FFF5 00F5 00F5"
	$"00F8 2AF7 F5F8 00F5 002B FF00 0000 0000"
	$"FF00 F5FD FAF9 FDFD F600 FD00 F5FD FDFD"
	$"F5FD FDF7 FDFD FDFD F52B FF00 0000 0000"
	$"FF00 00F5 FDF8 F7F6 00FD F8F8 00F5 00F5"
	$"F6F7 2AF7 F5F7 F6F5 002B FF00 0000 0000"
	$"FF00 F500 F5FD FFFF FDF8 F7F5 F8F8 F500"
	$"F82A 2AF7 F5F5 F800 F5F8 FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F8 2AF7 F5F5 F8F8"
	$"F82A 2AF7 F5F5 F8F8 F82B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F82A F7F5 F5F5"
	$"F82A 2AF7 F5F5 F82A 2A2B FF00 0000 0000"
	$"FF00 00F5 00FD FFFF FDF5 F82A 2AF7 F5F8"
	$"2A2A 2AF7 F5F5 F5F8 2AF7 FF00 0000 0000"
	$"FF00 F500 FDF6 F500 F6FD F5F8 2A2A F7F8"
	$"2A2A 2AF7 F5F5 F5F8 F72B FF00 0000 0000"
	$"FF00 00FD F6F5 00F6 2BF7 FDF8 2AF8 F8F7"
	$"2A2A 2AF7 F5F5 F5F7 F8F8 FF00 0000 0000"
	$"FF00 F5FF F500 F62B F7F8 FFF8 F8F5 F5F5"
	$"F72A 2AF7 F5F5 F72A 2A2B FF00 0000 0000"
	$"FF00 00FF 00F6 2BF7 F8F9 FFF5 F5F5 F5F5"
	$"F5F7 2AF7 F5F7 2A2A 2A2B FF00 0000 0000"
	$"FF00 F5FD F62B F7F8 F9FA FDF5 F5FD FDFD"
	$"F5FD FDF7 FDFD FDFD 2A2B FFFC 0000 0000"
	$"FF00 F8F8 FDF7 F8F9 FAFD F7F7 F7F7 F7F7"
	$"F7F7 F7F7 F7F7 F7F7 F7F7 FFFC FCFC 0000"
	$"FF00 F500 F5FD FFFF FD2A 2A2A 2A2A 2A2A"
	$"2A2A F7F7 F7F5 F5F5 F52B FFFC FCFC FCFC"
	$"FF00 00F5 00F5 00F8 F8F7 2A2A 2A2A 2A2A"
	$"2AF7 F5F7 2AF7 F5F5 F52B FFFC FCFC FCFC"
	$"FF00 F500 F500 F500 F5F6 F8F8 F72A 2A2A"
	$"F7F5 F5F7 2A2A F7F5 F52B FFFC FCFC 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFC"
};

resource 'icl8' (131) {
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF 0000 0000 0000 0000 0000"
	$"FF00 FFFF FFFF FFF5 F5FF F5F5 F5FF FFFF"
	$"F5F5 2BFF FFF8 FF00 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF F52B"
	$"FFF5 FFF5 FF00 F8FF 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF F5F5"
	$"FFF5 2BFF FF00 00F8 FF00 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5FB FFFF FFFB F5FF F52B"
	$"FFF5 F5F5 FFF5 F6F6 F8FF 0000 0000 0000"
	$"FF00 F5F5 FFF5 F6FF F5F5 F5FF F6FF FFFF"
	$"F5F5 FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F9 F9F9 F9F9 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00FA"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F5F9 5600"
	$"FA00 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00FF 00FA"
	$"FAFA 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F5F9 5600 FAFA"
	$"FAFA FA00 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00FF 00FA FAFA"
	$"FAFA FAFA 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F5F9 5600 FAFA FAFA"
	$"FAFA F8FF FF00 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00FF 00FA FAFA FAFA"
	$"FAF8 FFFF 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F5F9 5600 FAFA FAFA FAFA"
	$"F8FF FFFF F900 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00FF 00FA FAFA FAFA FAF8"
	$"FFFF 00FB FAF5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F5F9 5600 FAFA FAFA FAFA F8FF"
	$"FFFF F9FB FA00 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FA FFF8 FAFA FAFA FAF8 FFFF"
	$"00FB FAF5 FAF5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F5FA FFFA F8FA FAFA F8FF FFFF"
	$"F9FB FA00 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FA FFFA FAF8 FAF8 FFFF 00FB"
	$"FAF5 FAF5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F5FA F5FF FAFA F8FF FFFF F9FB"
	$"FA00 F500 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00FA 00F5 FFFA FAFF 00FB FAF5"
	$"FAF5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F5FF FAFF F9FB FA00"
	$"F500 F500 F500 F500 F52B FFFC 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 FFF5 FAF5 FAF5"
	$"00F5 00F5 00F5 00F5 002B FFFC FCFC 0000"
	$"FF00 F500 F500 F500 F500 F500 FA00 F500"
	$"F500 F500 F500 F500 F52B FFFC FCFC FCFC"
	$"FF00 00F5 00F5 00F5 00F5 00F5 FAF5 00F5"
	$"00F5 00F5 00F5 00F5 002B FFFC FCFC FCFC"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F500 F500 F500 F52B FFFC FCFC 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFC"
};

resource 'icl8' (132) {
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FF00 0000 0000 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 FFFF 0000 0000 0000 0000 0000"
	$"FF00 FFFF FFFF FFF5 F5FF F5F5 F5FF FFFF"
	$"F5F5 2BFF FFF8 FF00 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F5 FBF5 FBF5 F5FF F52B"
	$"FFF5 FFF5 FF00 F8FF 0000 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5F6 FFF5 FFF6 F5FF F5F5"
	$"FFF5 2BFF FF00 00F8 FF00 0000 0000 0000"
	$"FF00 F5F5 FFF5 F5FB FFFF FFFB F5FF F52B"
	$"FFF5 F5F5 FFF5 F6F6 F8FF 0000 0000 0000"
	$"FF00 F5F5 FFF5 F6FF F5F5 F5FF F6FF FFFF"
	$"F5F5 FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F5F5 F5F9 F9F9 F9F9 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 00F5 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F5F8 F500 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 00F8 00F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F500 F8F6 F800 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F5 F8F6 F8F5 00F5 002B FF00 0000 0000"
	$"FF00 F500 F500 F500 F500 F500 F500 F500"
	$"F5F6 F7F6 F7F6 F500 F52B FF00 0000 0000"
	$"FF00 00F5 00F5 00F5 00F5 00F5 00F5 00F5"
	$"00F8 2AF7 F5F8 00F5 002B FFFF 0000 0000"
	$"FF00 F500 F500 F5FF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FF16 FF00 0000"
	$"FF00 00F5 00F5 00F5 FF16 1616 1616 1616"
	$"1616 1616 1616 1616 1616 16D8 FF00 0000"
	$"FF00 F500 F500 F500 F5FF D8D8 D8D8 D8D8"
	$"D8D8 D8D8 D8D8 D8D8 D8D8 D8D8 FF00 0000"
	$"FF00 00F5 00F5 00F5 00F7 FFD8 D8D8 D8D8"
	$"D8D8 D8D8 D8D8 D8D8 D8D8 D8D8 FF00 0000"
	$"FF00 F500 F500 F500 F5FF D8D8 D8D8 D8D8"
	$"D8D8 D8D8 D8D8 D8D8 D8D8 D8D8 FF00 0000"
	$"FF00 00F5 00F5 00F5 FFD8 D8D8 D8D8 D8D8"
	$"D8D8 D8D8 D8D8 D8D8 D8D8 D8D8 FF00 0000"
	$"FF00 F500 F500 F5FF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"
	$"FF00 00F5 00F5 00F5 2B2B 2BF8 54FA FAF9"
	$"5454 54F9 2B2B 2BF9 F9FA FF00 0000 0000"
	$"FF00 F500 F500 F500 F5F5 F8F8 F8F5 F5F5"
	$"F72A 2AF7 F5F5 F72A 2A54 FF00 0000 0000"
	$"FF00 00F5 00F5 F6F8 F8F7 F5F5 F5F5 F5F5"
	$"F5F7 2AF7 F5F7 2A2A 2A54 FF00 0000 0000"
	$"FF00 F5F6 F8F8 F7F5 F5F5 F5F5 F5F5 F5F5"
	$"F5F5 F7F7 F72A 2A2A 2A54 FFFC 0000 0000"
	$"FF00 F8F8 F6F6 F6F7 F7F7 F7F7 F7F7 F7F7"
	$"F7F7 F7F7 F7F7 F7F7 F7F7 FFFC FCFC 0000"
	$"FF00 F5F6 F8F8 F72A 2A2A 2A2A 2A2A 2A2A"
	$"2A2A F7F7 F7F5 F5F5 F5F6 FFFC FCFC FCFC"
	$"FF00 00F5 00F5 F6F8 F8F7 2A2A 2A2A 2A2A"
	$"2AF7 F5F7 2AF7 F5F5 F5F6 FFFC FCFC FCFC"
	$"FF00 F500 F500 F500 F5F6 F8F8 F82A 2A2A"
	$"F7F5 F5F7 2A2A F7F5 F5F6 FFFC FCFC 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
	$"FFFF FFFF FFFF FFFF FFFF FFFC"
};

// ---------------------------------------------------------------------------------------
// -- Small icons.

// ...............................................
// .. ics#

resource 'ics#' (128) {
	{	/* array: 2 elements */
		/* [1] */
		$"0000 FFFC 8007 8005 FFDF 802A 8156 82AB"
		$"9ED1 90E1 959D B107 CFE4 B11C 8924 FFFC",
		/* [2] */
		$"0000 FFFC FFFF FFFF FFFF FFFE FFFE FFFF"
		$"FFFF FFFF FFFF FFFF FFFC FFFC FFFC FFFC"
	}
};

resource 'ics#' (129) {
	{	/* array: 2 elements */
		/* [1] */
		$"FF80 80C0 80A0 FF90 80F8 8108 8108 8288"
		$"9EF8 9938 9558 B118 CFF8 B11E 996F FFFE",
		/* [2] */
		$"FF80 FFC0 FFE0 FFF0 FFF8 FFF8 FFF8 FFF8"
		$"FFF8 FFF8 FFF8 FFF8 FFF8 FFFE FFFF FFFE"
	}
};

resource 'ics#' (130) {
	{	/* array: 2 elements */
		/* [1] */
		$"FF80 80C0 80A0 FF90 80F8 9808 BC08 BDC8"
		$"9808 8008 9808 A408 A5C8 980E 800F FFFE",
		/* [2] */
		$"FF80 FFC0 FFE0 FFF0 FFF8 FFF8 FFF8 FFF8"
		$"FFF8 FFF8 FFF8 FFF8 FFF8 FFFE FFFF FFFE"
	}
};

resource 'ics#' (131) {
	{	/* array: 2 elements */
		/* [1] */
		$"FF80 80C0 80A0 FF90 80F8 8108 8288 85C8"
		$"8B48 96C8 BD48 AB08 B508 AC0E 840F FFFE",
		/* [2] */
		$"FF80 FFC0 FFE0 FFF0 FFF8 FFF8 FFF8 FFF8"
		$"FFF8 FFF8 FFF8 FFF8 FFF8 FFFE FFFF FFFE"
	}
};

resource 'ics#' (132) {
	{	/* array: 2 elements */
		/* [1] */
		$"FF80 80C0 80A0 FF90 80F8 8008 8008 800C"
		$"8FF4 8404 8204 8404 8FF8 800E 800F FFFE",
		/* [2] */
		$"FF80 FFC0 FFE0 FFF0 FFF8 FFF8 FFF8 FFFC"
		$"FFFC FFFC FFFC FFFC FFF8 FFFE FFFF FFFE"
	}
};

// ...............................................
// .. ics4

resource 'ics4' (128) {
	$"0000 0000 0000 0000 FFFF FFFF FFFF FF00"
	$"F000 0000 0000 0DFF F000 0000 0000 0F4F"
	$"FFFF FFFF FF0F FF1F F000 000C 00FD F1F0"
	$"F000 000E 0FDF 1FF0 F000 00DD FDF1 FDFF"
	$"F00E EDE5 FF1F DCCF F00E 5765 FFFD CCCF"
	$"F00D 656F FDDF FFDF F0DE 7765 7665 5DFF"
	$"FE55 5555 5555 5F00 F0DE 6675 677E EF00"
	$"F00D A775 66EC 0F00 FFFF FFFF FFFF FF"
};

resource 'ics4' (129) {
	$"FFFF FFFF F000 0000 F000 0000 FF00 0000"
	$"F000 0000 F0F0 0000 FFFF FFFF F00F 0000"
	$"F000 0000 FFFF F000 F000 000C 0CCC F000"
	$"F000 000E 000C F000 F000 00DD D00C F000"
	$"F00E EDED EDEE F000 F00E DC7D C7DE F000"
	$"F00D 7D7D CDCD F000 F0DE CC7D C77A F000"
	$"FEDD DDDD DDDD F000 F0DE 77CD 7CCA FEE0"
	$"F00D ACCD 7DAC FEEE FFFF FFFF FFFF FEE0"
};

resource 'ics4' (130) {
	$"FFFF FFFF F000 0000 F000 0000 FF00 0000"
	$"F000 0000 F0F0 0000 FFFF FFFF F00F 0000"
	$"F000 0000 FFFF F000 F00F F000 0CCC F000"
	$"F0FF AF00 C00C F000 F0FA EF0F FF0C F000"
	$"F00F F00C 0C0C F000 F000 0CCC 0CCC F000"
	$"F00F FC00 C0CC F000 F0FC CFC0 C0CC F000"
	$"F0FC DF0F FFCC F000 FCCF FCCC CCCC FEE0"
	$"F00C C000 C00C FEEE FFFF FFFF FFFF FEE0"
};

resource 'ics4' (131) {
	$"FFFF FFFF F000 0000 F000 0000 FF00 0000"
	$"F000 0000 F0F0 0000 FFFF FFFF F00F 0000"
	$"F000 0000 FFFF F000 F000 000F 0CCC F000"
	$"F000 00FC F00C F000 F000 0ACD DA0C F000"
	$"F000 ACDD CE0C F000 F00A CDDC AE0C F000"
	$"F0AE DDCA 0E0C F000 F0ED ACAE 000C F000"
	$"F0E0 DA0E 000C F000 F000 0E00 000C FEE0"
	$"F000 0E00 000C FEEE FFFF FFFF FFFF FEE0"
};

resource 'ics4' (132) {
	$"FFFF FFFF F000 0000 F000 0000 FF00 0000"
	$"F000 0000 F0F0 0000 FFFF FFFF F00F 0000"
	$"F000 0000 FFFF F000 F000 000C 0CCC F000"
	$"F000 000C 000C F000 F000 00CC C00C FF00"
	$"F00C FFFF FFFF 2F00 F00C CF22 2222 3F00"
	$"F00C CCF3 3333 3F00 F0CC 0F33 3333 3F00"
	$"FCCC FFFF FFFF F000 F0CC CC0C C00C FEE0"
	$"F00C C00C CCCC FEEE FFFF FFFF FFFF FEE0"
};

// ...............................................
// .. ics8

resource 'ics8' (128) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF 0000"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5FA FFFF"
	$"FF00 F5F5 F5F5 F5F5 F5F5 F5F5 F5FF 13FF"
	$"FFFF FFFF FFFF FFFF FFFF F5FF FFFF 05FF"
	$"FF00 00F5 00F5 00F8 00F5 FF33 FF05 FF00"
	$"FF00 F500 F500 F5FC F5FF 33FF 05FF FF00"
	$"FF00 00F5 00F5 FA7F FF33 FF05 FF33 FFFF"
	$"FF00 F5FB FBFA FC7F FFFF 05FF 3308 08FF"
	$"FF00 00FB 7F2A 547F FFFF FF33 0808 08FF"
	$"FF00 F5FA 547F 54FF FF7F 7FFF FFFF 33FF"
	$"FF00 FAFC 2A2A 547F 2A54 54B0 B0FA FFFF"
	$"FFFC 7F7F 7F7F 7F7F 7F7F 7F7F 7FFF 0000"
	$"FFF5 FAFC 5454 2A7F 542A 2AFC FCFF 0000"
	$"FF00 00FA FD2A 2A7F 5454 FCF8 00FF 0000"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
};

resource 'ics8' (129) {
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFFF 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFF5 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FF00 F5FF 0000 0000"
	$"FF00 F500 F500 F500 FFFF FFFF FF00 0000"
	$"FF00 00F5 00F5 00F8 00F8 F8F8 FF00 0000"
	$"FF00 F500 F500 F5FC F500 F52B FF00 0000"
	$"FF00 00F5 00F5 FA7F FAF5 002B FF00 0000"
	$"FF00 F5FB FBFA FC7F FCFA FBFB FF00 0000"
	$"FF00 00FB 7F2A 547F 2A54 7FFB FF00 0000"
	$"FF00 F5FA 547F 547F 2A7F 2AFA FF00 0000"
	$"FF00 FAFC 2A2A 547F 2A54 54FD FF00 0000"
	$"FFFC 7F7F 7F7F 7F7F 7F7F 7F7F FF00 0000"
	$"FF00 FAFC 5454 2A7F 542A 2AFD FFFC FC00"
	$"FF00 00FA FD2A 2A7F 547F FD2B FFFC FCFC"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFC FC"
};

resource 'ics8' (130) {
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"
	$"FFF5 F5F5 F5F5 F5F5 FFFF 0000 0000 0000"
	$"FFF5 F5F5 F5F5 F5F5 FFF5 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FF00 F5FF 0000 0000"
	$"FFF5 00F5 00F5 00F5 FFFF FFFF FF00 0000"
	$"FF00 F5FF FFF5 00F5 00F8 F8F8 FF00 0000"
	$"FFF5 FFFE FDFF F500 F800 F52B FF00 0000"
	$"FF00 FFFD FCFF 00FF FFFF 002B FF00 0000"
	$"FFF5 F5FF FFF5 F5F8 F6F8 F52B FF00 0000"
	$"FF00 F5F5 F52B F8F8 F6F8 F8F8 FF00 0000"
	$"FFF5 F5FF FF2B F82A F7F5 F82B FF00 0000"
	$"FF00 FFF6 F7FF FA2A F7F5 F8F8 FF00 0000"
	$"FFF5 FFF7 F9FF F5FF FFFF 2A2A FF00 0000"
	$"FFF8 F8FF FFF7 F7F7 F7F7 F7F7 FFFC FC00"
	$"FFF5 00F8 F82A 2AF6 F7F6 F5F5 FFFC FCFC"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFC FC"
};

resource 'ics8' (131) {
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFFF 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFF5 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FF00 F5FF 0000 0000"
	$"FF00 F500 F500 F500 FFFF FFFF FF00 0000"
	$"FF00 00F5 00F5 00FE F5F8 F8F8 FF00 0000"
	$"FF00 F500 F500 FEF6 FE00 F52B FF00 0000"
	$"FF00 00F5 00FD F6F9 F9FD 002B FF00 0000"
	$"FF00 F500 FDF6 F9F9 F8FC F52B FF00 0000"
	$"FF00 00FD F6F9 F9F8 FDFB 002B FF00 0000"
	$"FF00 FDFC F9F9 F8FD F5FB F52B FF00 0000"
	$"FF00 FBF9 FDF8 FDFB 00F5 002B FF00 0000"
	$"FF00 FB00 F9FD F5FB F500 F52B FF00 0000"
	$"FF00 00F5 00FB 00F5 00F5 002B FFFC FC00"
	$"FF00 F500 F5FB F500 F500 F52B FFFC FCFC"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFC FC"
};

resource 'ics8' (132) {
	$"FFFF FFFF FFFF FFFF FF00 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFFF 0000 0000 0000"
	$"FF00 F5F5 F5F5 F5F5 FFF5 FF00 0000 0000"
	$"FFFF FFFF FFFF FFFF FF00 F5FF 0000 0000"
	$"FF00 F500 F500 F500 FFFF FFFF FF00 0000"
	$"FF00 00F5 00F5 00F8 00F8 F8F8 FF00 0000"
	$"FF00 F500 F500 F5F7 F500 F52B FF00 0000"
	$"FF00 00F5 00F5 F754 F7F5 002B FFFF 0000"
	$"FF00 F5F8 FFFF FFFF FFFF FFFF 16FF 0000"
	$"FF00 00F8 54FF 1616 1616 1616 D8FF 0000"
	$"FF00 F5F7 2A54 FFD8 D8D8 D8D8 D8FF 0000"
	$"FFF5 F7F8 F5FF D8D8 D8D8 D8D8 D8FF 0000"
	$"FFF7 5454 FFFF FFFF FFFF FFFF FF00 0000"
	$"FFF5 F7F8 2A2A F554 2AF5 F5F8 FFFC FC00"
	$"FF00 00F7 F8F5 F554 2A7F F82B FFFC FCFC"
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFC FC"
};
